==========
 z3c.form
==========

.. image:: https://img.shields.io/pypi/v/z3c.form.svg
        :target: https://pypi.python.org/pypi/z3c.form/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/z3c.form.svg
        :target: https://pypi.org/project/z3c.form/
        :alt: Supported Python versions

.. image:: https://github.com/zopefoundation/z3c.form/actions/workflows/tests.yml/badge.svg
        :target: https://github.com/zopefoundation/z3c.form/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/z3c.form/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/z3c.form?branch=master

.. image:: https://readthedocs.org/projects/z3cform/badge/?version=latest
        :target: https://z3cform.readthedocs.io/en/latest/
        :alt: Documentation Status


``z3c.form`` provides an implementation for both HTML and JSON forms and
according widgets. Its goal
is to provide a simple API but with the ability to easily customize any data or
steps.

There are currently two maintained branches:

* `master <https://github.com/zopefoundation/z3c.form/tree/master>`_ with the
  latest changes
* `3.x <https://github.com/zopefoundation/z3c.form/tree/3.x>`_ without the
  object widget overhaul and still including the ``ObjectSubForm`` and
  the ``SubformAdapter``.

Documentation on this implementation and its API can be found at
https://z3cform.readthedocs.io/
